# coding: utf-8

# flake8: noqa

"""
    Visier Authentication APIs

    Visier APIs for authenticating with Visier. To use Visier's public APIs, you must first authenticate yourself as a Visier user who is allowed to use Visier APIs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.99201.1475"

# import ApiClient
from visier_api_core.api_response import ApiResponse
from visier_api_core.api_client import ApiClient, RequestSerialized
from visier_api_core.configuration import Configuration
from visier_api_core.rest import RESTClientObject, RESTResponseType
from visier_api_core.exceptions import OpenApiException, ApiTypeError, ApiValueError, ApiKeyError, ApiAttributeError, ApiException

